.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.prov.entities package
==============================

Modules
-------

.. toctree::
   :maxdepth: 1

   entities/oc_ocdm.prov.entities.snapshot_entity
